@@ -1,26 +1,22 @@
 package main
 
-import "fmt"
-
 type python struct {
 	language
-	venvName string
+
+	Venv string
 }
 
 const (
-	// DisplayVirtualEnv shows or hides the virtual env
-	DisplayVirtualEnv Property = "display_virtual_env"
+	// FetchVirtualEnv fetches the virtual env
+	FetchVirtualEnv Property = "fetch_virtual_env"
 )
 
 func (p *python) string() string {
-	if p.venvName == "" {
-		return p.language.string()
+	segmentTemplate := p.language.props.getString(SegmentTemplate, "")
+	if len(segmentTemplate) == 0 {
+		return p.legacyString()
 	}
-	version := p.language.string()
-	if version == "" {
-		return p.venvName
-	}
-	return fmt.Sprintf("%s %s", p.venvName, version)
+	return p.language.renderTemplate(segmentTemplate, p)
 }
 
 func (p *python) init(props properties, env environmentInfo) {
@@ -53,7 +49,7 @@ func (p *python) enabled() bool {
 }
 
 func (p *python) loadContext() {
-	if !p.language.props.getBool(DisplayVirtualEnv, true) {
+	if !p.language.props.getOneOfBool(DisplayVirtualEnv, FetchVirtualEnv, true) {
 		return
 	}
 	venvVars := []string{
@@ -67,14 +63,14 @@ func (p *python) loadContext() {
 		venv = p.language.env.getenv(venvVar)
 		name := base(venv, p.language.env)
 		if p.canUseVenvName(name) {
-			p.venvName = name
+			p.Venv = name
 			break
 		}
 	}
 }
 
 func (p *python) inContext() bool {
-	return p.venvName != ""
+	return p.Venv != ""
 }
 
 func (p *python) canUseVenvName(name string) bool {
